Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog`_,
and this project adheres to `Semantic Versioning`_.


Version 1.0.1 (2021/06/10)
--------------------------

* Fixed: broken package due to missing ``__init_.py`` file


Version 1.0.0 (2021/06/09)
--------------------------

* Added: initial public release


.. _Keep a Changelog: https://keepachangelog.com/en/1.0.0/
.. _Semantic Versioning: https://semver.org/spec/v2.0.0.html
